@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: FastDisplayModelBuilder.java,v 1.4 2007/04/02 11:41:16 taqua Exp $
+ * $Id: FastDisplayModelBuilder.java 3524 2007-10-16 11:26:31Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -65,7 +65,7 @@ public class FastDisplayModelBuilder implements ModelBuilder
     private int suspendCounter;
     private State contentGeneratorState;
 
-    public FastDisplayModelBuilderState(FastDisplayModelBuilder builder)
+    private FastDisplayModelBuilderState(final FastDisplayModelBuilder builder)
         throws StateException
     {
       this.contentGeneratorState = builder.contentGenerator.saveState();
@@ -97,12 +97,12 @@ public class FastDisplayModelBuilder implements ModelBuilder
      * @throws org.jfree.layouting.StateException
      *
      */
-    public StatefullComponent restore(LayoutProcess layoutProcess)
+    public StatefullComponent restore(final LayoutProcess layoutProcess)
         throws StateException
     {
       try
       {
-        FastDisplayModelBuilder fmb = new FastDisplayModelBuilder();
+        final FastDisplayModelBuilder fmb = new FastDisplayModelBuilder();
         fmb.layoutProcess = layoutProcess;
         fmb.flowContexts = new FastStack();
         fmb.suspendCounter = suspendCounter;
@@ -694,9 +694,9 @@ public class FastDisplayModelBuilder implements ModelBuilder
       return false;
     }
 
-    IntList roles = new IntList(5);
-    IntList models = new IntList(5);
-    FastStack contexts = new FastStack();
+    final IntList roles = new IntList(5);
+    final IntList models = new IntList(5);
+    final FastStack contexts = new FastStack();
     while (fc.getCurrentState() == FlowContext.STATE_SUSPEND)
     {
       contexts.push(fc.getCurrentLayoutContext());
