@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: RenderBox.java,v 1.35 2007/04/27 12:34:51 taqua Exp $
+ * $Id: RenderBox.java 3524 2007-10-16 11:26:31Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -305,12 +305,12 @@ public abstract class RenderBox extends RenderNode
    * @param node
    * @param target
    */
-  protected void insertAfter(RenderNode node, RenderNode target)
+  protected void insertAfter(final RenderNode node, final RenderNode target)
   {
     if (node == null)
     {
       // ok, insert as new first element.
-      RenderNode firstChild = getFirstChild();
+      final RenderNode firstChild = getFirstChild();
       if (firstChild == null)
       {
         setLastChild(target);
@@ -360,11 +360,11 @@ public abstract class RenderBox extends RenderNode
    * @param node
    * @param target
    */
-  protected void insertBefore(RenderNode node, RenderNode target)
+  protected void insertBefore(final RenderNode node, final RenderNode target)
   {
     if (node == null)
     {
-      RenderNode lastChild = getLastChild();
+      final RenderNode lastChild = getLastChild();
       if (lastChild == null)
       {
         target.setParent(this);
@@ -511,7 +511,7 @@ public abstract class RenderBox extends RenderNode
       }
 
 
-      RenderNode node = replacement[i];
+      final RenderNode node = replacement[i];
 
       last.setNext(node);
       node.setPrev(last);
@@ -550,7 +550,7 @@ public abstract class RenderBox extends RenderNode
       old.updateChangeTracker();
       for (int i = 0; i < replacement.length; i++)
       {
-        RenderNode renderNode = replacement[i];
+        final RenderNode renderNode = replacement[i];
         renderNode.updateChangeTracker();
       }
       return;
@@ -565,7 +565,7 @@ public abstract class RenderBox extends RenderNode
       lastChild = last;
       for (int i = 0; i < replacement.length; i++)
       {
-        RenderNode renderNode = replacement[i];
+        final RenderNode renderNode = replacement[i];
         renderNode.updateChangeTracker();
       }
       return;
@@ -588,7 +588,7 @@ public abstract class RenderBox extends RenderNode
 
     for (int i = 0; i < replacement.length; i++)
     {
-      RenderNode renderNode = replacement[i];
+      final RenderNode renderNode = replacement[i];
       renderNode.updateChangeTracker();
     }
   }
@@ -623,9 +623,9 @@ public abstract class RenderBox extends RenderNode
    *
    * @return
    */
-  public RenderNode derive(boolean deepDerive)
+  public RenderNode derive(final boolean deepDerive)
   {
-    RenderBox box = (RenderBox) super.derive(deepDerive);
+    final RenderBox box = (RenderBox) super.derive(deepDerive);
 
     if (deepDerive)
     {
@@ -633,7 +633,7 @@ public abstract class RenderBox extends RenderNode
       RenderNode currentNode = null;
       while (node != null)
       {
-        RenderNode previous = currentNode;
+        final RenderNode previous = currentNode;
 
         currentNode = node.derive(true);
         currentNode.setParent(box);
@@ -673,13 +673,13 @@ public abstract class RenderBox extends RenderNode
    */
   public RenderNode hibernate()
   {
-    RenderBox box = (RenderBox) super.hibernate();
+    final RenderBox box = (RenderBox) super.hibernate();
 
     RenderNode node = firstChild;
     RenderNode currentNode = null;
     while (node != null)
     {
-      RenderNode previous = currentNode;
+      final RenderNode previous = currentNode;
 
       currentNode = node.hibernate();
       currentNode.setParent(box);
@@ -711,16 +711,16 @@ public abstract class RenderBox extends RenderNode
    *
    * @return
    */
-  public RenderNode deriveFrozen(boolean deepDerive)
+  public RenderNode deriveFrozen(final boolean deepDerive)
   {
-    RenderBox box = (RenderBox) super.deriveFrozen(deepDerive);
+    final RenderBox box = (RenderBox) super.deriveFrozen(deepDerive);
     if (deepDerive)
     {
       RenderNode node = firstChild;
       RenderNode currentNode = null;
       while (node != null)
       {
-        RenderNode previous = currentNode;
+        final RenderNode previous = currentNode;
 
         currentNode = node.deriveFrozen(true);
         currentNode.setParent(box);
@@ -759,7 +759,7 @@ public abstract class RenderBox extends RenderNode
     }
   }
 
-  public RenderNode findNodeById(Object instanceId)
+  public RenderNode findNodeById(final Object instanceId)
   {
     if (instanceId == getInstanceId())
     {
@@ -794,7 +794,7 @@ public abstract class RenderBox extends RenderNode
     final RenderNode lastChild = getLastChild();
     if (lastChild instanceof RenderBox)
     {
-      RenderBox lcBox = (RenderBox) lastChild;
+      final RenderBox lcBox = (RenderBox) lastChild;
       if (lcBox.isAppendable())
       {
         return lcBox.getInsertationPoint();
@@ -816,7 +816,7 @@ public abstract class RenderBox extends RenderNode
     RenderNode child = getFirstChild();
     while (child != null)
     {
-      RenderNode nextChild = child.getNext();
+      final RenderNode nextChild = child.getNext();
       if (child != getFirstChild())
       {
         child.getPrev().setNext(null);
@@ -879,7 +879,7 @@ public abstract class RenderBox extends RenderNode
       return false;
     }
 
-    RenderNode node = getFirstNonEmpty();
+    final RenderNode node = getFirstNonEmpty();
     if (node != null)
     {
       return false;
@@ -955,7 +955,7 @@ public abstract class RenderBox extends RenderNode
     }
   }
 
-  public void remove(RenderNode child)
+  public void remove(final RenderNode child)
   {
     final RenderBox parent = child.getParent();
     if (parent != this)
@@ -965,8 +965,8 @@ public abstract class RenderBox extends RenderNode
 
     child.setParent(null);
 
-    RenderNode prev = child.getPrev();
-    RenderNode next = child.getNext();
+    final RenderNode prev = child.getPrev();
+    final RenderNode next = child.getNext();
 
     if (prev != null)
     {
